@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.documentai_v1beta2 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -170,9 +181,9 @@ class DocumentUnderstandingServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DocumentUnderstandingServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the document understanding service client.
@@ -216,13 +227,15 @@ class DocumentUnderstandingServiceAsyncClient:
 
     async def batch_process_documents(
         self,
-        request: Union[
-            document_understanding.BatchProcessDocumentsRequest, dict
+        request: Optional[
+            Union[document_understanding.BatchProcessDocumentsRequest, dict]
         ] = None,
         *,
-        requests: Sequence[document_understanding.ProcessDocumentRequest] = None,
+        requests: Optional[
+            MutableSequence[document_understanding.ProcessDocumentRequest]
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""LRO endpoint to batch process many documents. The output is
@@ -257,17 +270,17 @@ class DocumentUnderstandingServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.documentai_v1beta2.types.BatchProcessDocumentsRequest, dict]):
+            request (Optional[Union[google.cloud.documentai_v1beta2.types.BatchProcessDocumentsRequest, dict]]):
                 The request object. Request to batch process documents
                 as an asynchronous operation. The output is written to
                 Cloud Storage as JSON in the [Document] format.
-            requests (:class:`Sequence[google.cloud.documentai_v1beta2.types.ProcessDocumentRequest]`):
+            requests (:class:`MutableSequence[google.cloud.documentai_v1beta2.types.ProcessDocumentRequest]`):
                 Required. Individual requests for
                 each document.
 
@@ -350,10 +363,12 @@ class DocumentUnderstandingServiceAsyncClient:
 
     async def process_document(
         self,
-        request: Union[document_understanding.ProcessDocumentRequest, dict] = None,
+        request: Optional[
+            Union[document_understanding.ProcessDocumentRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document.Document:
         r"""Processes a single document.
@@ -389,7 +404,7 @@ class DocumentUnderstandingServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.documentai_v1beta2.types.ProcessDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.documentai_v1beta2.types.ProcessDocumentRequest, dict]]):
                 The request object. Request to process one document.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -453,14 +468,9 @@ class DocumentUnderstandingServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-documentai",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DocumentUnderstandingServiceAsyncClient",)
